package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.entity.TaPreselectionRecord;
import com.huiju.estateagents.mapper.TaHousingResourcesMapper;
import com.huiju.estateagents.mapper.TaPreselectionRecordMapper;
import com.huiju.estateagents.po.TaPreselectionRecordPO;
import com.huiju.estateagents.service.ITaPreselectionRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 预选记录表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Service
public class TaPreselectionRecordServiceImpl extends ServiceImpl<TaPreselectionRecordMapper, TaPreselectionRecord> implements ITaPreselectionRecordService {

    private Logger logger = LoggerFactory.getLogger(TaPreselectionRecordServiceImpl.class);

    @Autowired
    private TaPreselectionRecordMapper taPreselectionRecordMapper;

    @Autowired
    private TaHousingResourcesMapper taHousingResourcesMapper;

    @Override
    public IPage<TaPreselectionRecordPO> listPreselectionRecord(Integer pageNum, Integer pageSize, String personId) {
        logger.info("listPreselectionRecord 接收参数：pageNum：{}，pageSize：{}，personId：{}", pageNum, pageSize, personId);

        IPage<TaPreselectionRecordPO> iPage = new Page<>(pageNum, pageSize);
        return taPreselectionRecordMapper.listPreselectionRecord(iPage, personId);
    }

    @Override
    @Transactional
    public Boolean taPreselectionRecordAdd(TaPreselectionRecord taPreselectionRecord) {
        logger.info("listPreselectionRecord 接收参数：taPreselectionRecord:{}", JSONObject.toJSONString(taPreselectionRecord));

        // 添加预选记录
        taPreselectionRecord.setStatus(1);
        taPreselectionRecord.setCreateDate(LocalDateTime.now());
        save(taPreselectionRecord);

        // 更新房源表热度
        return taHousingResourcesMapper.updateForAddHeat(taPreselectionRecord.getHouseId());
    }

    @Override
    @Transactional
    public Boolean taPreselectionRecordCancel(String personId, String houseId) {
        logger.info("taPreselectionRecordCancel 接收参数：personId：{}，houseId：{}", personId, houseId);

        // 更新预选记录
        TaPreselectionRecord record = new TaPreselectionRecord();
        record.setPreselectionRecordId(Integer.parseInt(personId));
        record.setStatus(0);
        record.setUpdateDate(DateUtils.today());
        updateById(record);

        // 更新房源表热度
        return taHousingResourcesMapper.updateForSubtractHeat(houseId);
    }

    @Override
    public TaPreselectionRecord checkPreselect(String personId, String houseId) {
        logger.info("checkPreselect 接收参数：personId：{}，houseId：{}", personId, houseId);

        return taPreselectionRecordMapper.getRecordByPersonIdAndHouseId(personId, houseId);
    }
}
